@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Device::BusPirate::Mode );
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Carp;
 
@@ -21,6 +21,24 @@ use constant MODE => "I2C";
 
 C<Device::BusPirate::Mode::I2C> - use C<Device::BusPirate> in I2C mode
 
+=head1 SYNOPSIS
+
+ use Device::BusPirate;
+
+ my $pirate = Device::BusPirate->new;
+ my $i2c = $pirate->enter_mode( "I2C" )->get;
+
+ my $addr = 0x20;
+
+ my $count = 0;
+ while(1) {
+    $i2c->send( $addr, chr $count )->get;
+    my $in = ord $i2c->recv( $addr, 1 )->get;
+    printf "Read %02x\n", $in;
+
+    $count++; $count %= 255;
+ }
+
 =head1 DESCRIPTION
 
 This object is returned by a L<Device::BusPirate> instance when switching it
